Class: String

Inherits:
Object
  • Object
show all
Defined in:
lib/trunk_spec_helper.rb

Overview

String is an override to the main String class that is used to colorize the output it is used to make the output more readable

Instance Method Summary collapse

Instance Method Details

#colorize(color_code) ⇒ Object



45
46
47
# File 'lib/trunk_spec_helper.rb', line 45

def colorize(color_code)
  "\e[#{color_code}m#{self}\e[0m"
end

#greenObject



53
54
55
# File 'lib/trunk_spec_helper.rb', line 53

def green
  colorize(32)
end

#redObject



49
50
51
# File 'lib/trunk_spec_helper.rb', line 49

def red
  colorize(31)
end

#yellowObject



57
58
59
# File 'lib/trunk_spec_helper.rb', line 57

def yellow
  colorize(33)
end