Class: String

Inherits:
Object
  • Object
show all
Defined in:
lib/trunk_spec_helper.rb

Overview

String is an override to the main String class that is used to colorize the output it is used to make the output more readable

Instance Method Summary collapse

Instance Method Details

#colorize(color_code) ⇒ Object



40
41
42
# File 'lib/trunk_spec_helper.rb', line 40

def colorize(color_code)
  "\e[#{color_code}m#{self}\e[0m"
end

#greenObject



48
49
50
# File 'lib/trunk_spec_helper.rb', line 48

def green
  colorize(32)
end

#redObject



44
45
46
# File 'lib/trunk_spec_helper.rb', line 44

def red
  colorize(31)
end

#yellowObject



52
53
54
# File 'lib/trunk_spec_helper.rb', line 52

def yellow
  colorize(33)
end